mod structs;
mod traits;
use crate::structs::cash::Cash;
use crate::structs::cash::create::Procedures;
use crate::structs::cash::calculate::Operations;

fn cristi() {
    let wallet: Cash = Cash::create(String::from("eur"), 2);

    let newcacat = wallet.add(3);

    println!("{}", newcacat.currency());
}




